#
# spec file for package python-dpkt
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-dpkt
Version:        1.9.7.2
Release:        150400.1.6
Summary:        Packet creation and parsing module for Python
License:        BSD-3-Clause
Group:          Development/Libraries/Python
URL:            https://github.com/kbandla/dpkt
Source:         https://github.com/kbandla/dpkt/archive/v%{version}.tar.gz
# PATCH-FIX-UPSTREAM skip-BE-tests.patch gh#kbandla/dpkt#505 mcepl@suse.com
# Adjust tests to work on BE machines, gh#kbandla/dpkt#615
Patch0:         skip-BE-tests.patch
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
A packet creation / parsing module for Python, with definitions for
the basic TCP/IP protocols.

%prep
%setup -q -n dpkt-%{version}
%autopatch -p1

# do not add extra pytest argumetns
sed -i -e '/addopts=/d' setup.cfg

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest dpkt

%files %{python_files}
%license LICENSE
%doc examples AUTHORS README.md docs
%{python_sitelib}/*

%changelog
* Fri Oct  8 2021 mcepl@suse.com
- Update skip-BE-tests.patch so that it actually fixes things,
  instead of just skipping tests (gh#kbandla/dpkt#615).
* Thu Oct  7 2021 mcepl@suse.com
- Update to 1.9.7.2:
  - Fixed performance regression (#611)
  - Moved the project documentation from Read the Docs(RST) to
    github.io(MarkDown)
  - Added a new mechanism for creating bit-sized field
    definitions in the protocol parsers (Packet.__bit_fields__)
  - Added pretty printing capability aka Packet.pprint(),
    Packet.__pprint_funcs__
  - Added documentation on developing protocol parsers in dpkt
    (creating_parsers.md)
  - Added a universal pcap+pcapng reader
    (dpkt.pcap.UniversalReader)
  - Improved TLS ClientHello and ServerHello parsing: return an
    "Unknown" ciphersuite instead of raising an exception, add
    codes for rfc8701, GREASE ciphersutes
  - Added function to get IP protocol name
  - Modified Packet.__getitem__() and added Packet.__contains__()
    to address the nested protocol layers
  - Fixed payload length interpretation in AH decoder
  - Improved handling of invalid chunks in HTTP and SCTP
  - Fixed decoding of IPv6 fragments after the 1st fragment
  - Support rfc3540 nonce sum flag in TCP
  - Added in the TLS 1.3 Cipher Suite from the RFC 8446 dated
    August 2018
  - Added support for Linux cooked capture v2, SLL2.
  - New example showing how to process truncated DNS packets
    (examples/print_dns_truncated.py).
  - Corrected typo in BGP.notification attribute.
  - BGP.Update.Attribute.MPReachNLRI.SNPA now inherits from
    dpkt.Packet.
  - Byteorder is now specified when packing GRE optional fields.
  - #517: Improvement to Radiotap class, supporting multi-byte
    and misaligned flags fields. Endianness is now enforced.
  - Github issue template added for bug reporting.
  - Compliance with flake8 formatting.
  - asn1.py::utctime method now returns time in UTC, instead of
    local.
  - Allow multiple InterfaceDescriptionBlocks with pcapng.Writer.
  - SCTP decoder DATA chunk padding aligned to 4-bytes, and
    improved handling of .data field.
  - IEEE80211 DELBA frame now works on big and little-endian
    architectures.
  - Introduce compat.ntole which converts from network byte order
    to little-endian byte order, regardless of host endianness.
  - Ethernet class now attempts to unpack the padding and trailer
    if present.
  - Added anonymous property to cipher suites, which returns True
    if the cipher suite starts with 'anon'.
  - Added pfs (Perfect Forward Secrecy) and aead (Authenticated
    Encryption with Additional Data) properties to cipher suites.
  - Added old CHACHA20-POLY1305 related cipher suites to TLS
    CipherSuite list.
  - Remove redundant num_compression_methods from TLSClientHello
  - Testing improved from 90%% coverage to over 99%%.
- Remove upstreamed patch fix_s390x_tests.patch
- Add patch skip-BE-tests.patch skipping failing tests again
  (gh#kbandla/dpkt#505).
* Sun Jan  3 2021 mcepl@suse.com
- Rename skip_s390x_tests.patch to fix_s390x_tests.patch (from the
  upstream commit 4ce0b897e60a), which seems to fix the problem.
* Mon Dec 14 2020 mcepl@suse.com
- Add skip_s390x_tests.patch to skip failing tests on s390x
  (gh#kbandla/dpkt#505).
* Mon Dec 14 2020 mcepl@suse.com
- Update to 1.9.4:
  - drop python 2.6 support
  - add python 3.7, 3.8 support
  - fix netbios name encoding and decoding
  - properly set type of last vlan tag to type of eth.data layer
  - fix QinQ vlan tag parsing with miscellaneous data
  - add explicit iter to dpkt.Packet so dict() maps the fields nicely
  - fix ipv6 packet so that it can be used for generating IPv6 data
  - handle zero Eth type
  - python 3 compatibility fixes
* Mon Mar 18 2019 jengelh@inai.de
- Use noun phrase in descriptions.
* Mon Mar  4 2019 tchvatal@suse.com
- Update to 1.9.2:
  * Tiny fixes for 3.7 python
- Enable tests
- Add proper dependencies
* Wed Jan  3 2018 tchvatal@suse.com
- Update to version 1.9.1:
  * Allow building with python3
- Remove epydoc dependency so we can remove py2 only package
* Mon Aug 26 2013 Greg.Freemyer@gmail.com
- Update to version 1.8:
  * fix a typo in vrrp.py
  * fix IPv4 and IPv6 packet to correctly handle zero payload length
  * store cipher_suite as int in TLSServerHello to allow app-specific messages
  * improve SSL parsing
- Specfile changes
  * Update license field to BSD-3-clause
  * Update URL
  * remove make doc.  Doc is no longer provided other than the source code.
  * wrap site macros with a if for older versions of opensuse only
* Wed Jun  1 2011 saschpe@suse.de
- Update to version 1.7:
  * handle dynamic imports from py2exe/freeze.py/zipped egg
    packages, from plotnikoff
  * decode Ethernet MPLS labels, Cisco ISL VLAN tags, 802.2 LLC fields
  * handle multiply-defined HTTP headers from simdream
  * add IPv6 extension header support (minus ESP) from Owen Stephens
  * add radiotap module from Timur Alperovich
  * add IEEE80211 module from Jon Oberheide
  * add RFB module from Jon Oberheide
  * fix IP6 checksum to include options
  * rename 'as' to 'asn' field in BGP header
  * fix transport-layer checksum in IP6
  * handle improper TCP header offset
  * fix SSL typo
  * handle malformed ICMP headers
  * added RX module from Jon Oberheide
  * fixed loopback module IP/IP6 decoding
  * set transport-layer (TCP, UDP) checksum in IP
  * MRT module fixes
  * fix pcap.Writer timestamp calculation
- Spec file cleanup:
  * Added changes file and removed stuff from %%changelog section
  * Added license header
  * Removed authors from description
  * Don't cleanup buildroot in %%install section
  * Made it a noarch package
* Sun Jan 28 2007 judas_iscariote@shorewall.net
- Update to version 1.6
* Wed Sep  6 2006 jfunk@funktronics.ca
- Initial release
